From: Yinan <yinan.wang@intel.com>
To: dts@dpdk.org
Cc: Wang Yinan <yinan.wang@intel.com>
Subject: [dts] [PATCH v1] tests: update test commonds for vectorized cases in TestSuite_pvp_multi_paths_performance.py
Date: Wed, 29 Apr 2020 22:08:26 +0000 [thread overview]
Message-ID: <20200429220826.27662-1-yinan.wang@intel.com> (raw)
From: Wang Yinan <yinan.wang@intel.com>
Signed-off-by: Wang Yinan <yinan.wang@intel.com>
---
.../TestSuite_pvp_multi_paths_performance.py | 35 +++++++++++++------
1 file changed, 25 insertions(+), 10 deletions(-)
diff --git a/tests/TestSuite_pvp_multi_paths_performance.py b/tests/TestSuite_pvp_multi_paths_performance.py
index 092d98c..14a0fd7 100644
--- a/tests/TestSuite_pvp_multi_paths_performance.py
+++ b/tests/TestSuite_pvp_multi_paths_performance.py
@@ -106,6 +106,7 @@ class TestPVPMultiPathPerformance(TestCase):
for frame_size in self.frame_sizes:
tgen_input = []
self.throughput[frame_size] = dict()
+
self.logger.info("Test running at parameters: " +
"framesize: {}, rxd/txd: {}".format(frame_size, self.nb_desc))
rx_port = self.tester.get_local_port(
@@ -114,7 +115,6 @@ class TestPVPMultiPathPerformance(TestCase):
self.dut_ports[0])
destination_mac = self.dut.get_mac_address(
self.dut_ports[0])
-
pkt = Packet(pkt_type='UDP', pkt_len=frame_size)
pkt.config_layer('ether', {'dst': '%s' % destination_mac})
pkt.save_pcapfile(self.tester, "%s/multi_path.pcap" % (self.out_path))
@@ -122,9 +122,7 @@ class TestPVPMultiPathPerformance(TestCase):
self.tester.pktgen.clear_streams()
streams = self.pktgen_helper.prepare_stream_from_tginput(tgen_input, 100, None, self.tester.pktgen)
- # set traffic option
- traffic_opt = {'delay': 5}
- _, pps = self.tester.pktgen.measure_throughput(stream_ids=streams, options=traffic_opt)
+ _, pps = self.tester.pktgen.measure_throughput(stream_ids=streams)
Mpps = pps / 1000000.0
self.verify(Mpps > 0.0, "%s can not receive packets of frame size %d" % (self.running_case, frame_size))
@@ -344,7 +342,24 @@ class TestPVPMultiPathPerformance(TestCase):
"""
self.test_target = self.running_case
self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
- virtio_pmd_arg = {"version": "in_order=1,packed_vq=1,mrg_rxbuf=0",
+ virtio_pmd_arg = {"version": "in_order=1,packed_vq=1,mrg_rxbuf=0,vectorized=1",
+ "path": "--rx-offloads=0x10 --enable-hw-vlan-strip"}
+ self.start_vhost_testpmd()
+ self.start_virtio_testpmd(virtio_pmd_arg)
+ self.send_and_verify("virtio_1.1_inorder_normal")
+ self.close_all_testpmd()
+ self.logger.info('result of all framesize result')
+ self.result_table_print()
+ self.handle_expected()
+ self.handle_results()
+
+ def test_perf_pvp_virtio11_vectorized(self):
+ """
+ performance for PVP virtio1.1 Vectorized Path.
+ """
+ self.test_target = self.running_case
+ self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
+ virtio_pmd_arg = {"version": "in_order=1,packed_vq=1,mrg_rxbuf=0,vectorized=1",
"path": "--tx-offloads=0x0 --enable-hw-vlan-strip"}
self.start_vhost_testpmd()
self.start_virtio_testpmd(virtio_pmd_arg)
@@ -372,9 +387,9 @@ class TestPVPMultiPathPerformance(TestCase):
self.handle_expected()
self.handle_results()
- def test_perf_pvp_inorder_no_mergeable(self):
+ def test_perf_pvp_inorder_normal(self):
"""
performance for PVP In_order no_mergeable Path.
"""
self.test_target = self.running_case
self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
@@ -412,7 +427,7 @@ class TestPVPMultiPathPerformance(TestCase):
"""
self.test_target = self.running_case
self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
- virtio_pmd_arg = {"version": "packed_vq=0,in_order=0,mrg_rxbuf=0",
+ virtio_pmd_arg = {"version": "packed_vq=0,in_order=0,mrg_rxbuf=0,vectorized=1",
"path": "--tx-offloads=0x0 --enable-hw-vlan-strip"}
self.start_vhost_testpmd()
self.start_virtio_testpmd(virtio_pmd_arg)
@@ -425,11 +440,11 @@ class TestPVPMultiPathPerformance(TestCase):
def test_perf_pvp_vector_rx(self):
"""
- performance for PVP Vector Path
+ performance for PVP Vector_RX Path
"""
self.test_target = self.running_case
self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
- virtio_pmd_arg = {"version": "packed_vq=0,in_order=0,mrg_rxbuf=0",
+ virtio_pmd_arg = {"version": "packed_vq=0,in_order=0,mrg_rxbuf=0,vectorized=1",
"path": "--tx-offloads=0x0 "}
self.start_vhost_testpmd()
self.start_virtio_testpmd(virtio_pmd_arg)
@@ -372,9 +387,9 @@ class TestPVPMultiPathPerformance(TestCase):
"""
- performance for PVP In_order no_mergeable Path.
+ performance for PVP In_order Normal Path.
"""
self.test_target = self.running_case
--
2.17.1
next reply other threads:[~2020-04-30 5:14 UTC|newest]
Thread overview: 2+ messages / expand[flat|nested] mbox.gz Atom feed top
2020-04-29 22:08 Yinan [this message]
2020-05-06 3:25 ` Tu, Lijuan
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20200429220826.27662-1-yinan.wang@intel.com \
--to=yinan.wang@intel.com \
--cc=dts@dpdk.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).